@@ -2,13 +2,15 @@
 
 =head1 NAME
 
-soapcli - SOAP client for CLI with YAML and JSON input
+soapcli - SOAP client for CLI with YAML and JSON input and output
 
 =head1 SYNOPSIS
 
 B<soapcli>
 S<[--verbose|-v]>
 S<[--dump-xml-request|-x]>
+S<[--json|-j]>
+S<[--yaml|-y]>
 data.yml|data.json|{string:"JSON"}|-
 [webservice.wsdl|webservice_wsdl.url]
 [[http://example.com/endpoint|endpoint.url][#port]]
@@ -19,9 +21,9 @@ S<[--help|-h]>
 
 Examples:
 
-  $ soapcli -v calculator-correct.yml
+  $ soapcli calculator-correct.json
 
-  $ soapcli -v '{add:{x:2,y:2}}' http://soaptest.parasoft.com/calculator.wsdl
+  $ soapcli -y '{add:{x:2,y:2}}' http://soaptest.parasoft.com/calculator.wsdl
 
   $ soapcli -v globalweather.yml globalweather.url '#GlobalWeatherSoap'
 
@@ -49,6 +51,8 @@ name of port should start with C<#> character.
 The fourth argument is a name of method. It is optional if a name of method is
 already a part of request data.
 
+The result will be dumped as JSON (by default) or YAML.
+
 =cut
 
 
@@ -57,13 +61,26 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0300';
 
 require App::soapcli;
 
 App::soapcli->new_with_options->run;
 
 
+=head1 INSTALLATION
+
+=head2 Debian/Ubuntu
+
+  $ sudo apt-get install cpanminus build-essential libxml2-dev zlib1g-dev
+
+  $ sudo apt-get install libyaml-syck-perl libyaml-libyaml-perl \
+    libjson-pp-perl libhtml-tiny-perl libgetopt-long-descriptive-perl \
+    libperl6-slurp-perl libxml-libxml-simple-perl libtest-tester-perl \
+    libtest-nowarnings-perl libtest-deep-perl
+
+  $ sudo cpanm App::soapcli
+
 =head1 SEE ALSO
 
 L<http://github.com/dex4er/soapcli>.
@@ -81,7 +98,7 @@ Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright (c) 2011-2013 Piotr Roszatycki <dexter@cpan.org>.
+Copyright (c) 2011-2015 Piotr Roszatycki <dexter@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as perl itself.
